@@ -60,9 +60,9 @@ const (
 	Oas2APISchemes                       = "oas2-api-schemes"
 	Oas2Discriminator                    = "oas2-discriminator"
 	Oas2HostNotExample                   = "oas2-host-not-example"
-	Oas3HostNotExample                   = "oas3-host-not-example.com"
+	Oas3HostNotExample                   = "oas3-host-not-example"
 	Oas2HostTrailingSlash                = "oas2-host-trailing-slash"
-	Oas3HostTrailingSlash                = "oas3-host-trailing-slash"
+	Oas3HostTrailingSlash                = "oas3-server-trailing-slash"
 	Oas2ParameterDescription             = "oas2-parameter-description"
 	Oas3ParameterDescription             = "oas3-parameter-description"
 	Oas3OperationSecurityDefined         = "oas3-operation-security-defined"
